{% load i18n apphooks_config_tags %}
 <div class="aldryn aldryn-jobs aldryn-jobs-categories">
    {% if plugin_configuration_error %}
        {% if request.user.is_staff or request.user.is_superuser %}
            <p class="config-errors">{{ plugin_configuration_error }}</p>
        {% endif %}
    {% else %}
        <ul class="list-unstyled">
            {% for category in instance.categories %}
                <li>
                    <span class="badge">{{ category.count }}</span>
                    <a href="{% namespace_url "category-job-opening-list" category.slug namespace=instance.app_config.namespace %}">{{ category.name }}</a>
                </li>
            {% endfor %}
        </ul>
    {% endif %}
</div>
