{% load i18n %}

<div class="aldryn aldryn-jobs aldryn-jobs-latest">
    {% if plugin_configuration_error %}
        {% if request.user.is_staff or request.user.is_superuser %}
            <p class="alert alert-danger">{{ plugin_configuration_error }}</p>
        {% endif %}
    {% else %}
        <p class="alert alert-info">
            {% blocktrans count counter=vacancies_count %}
                Showing {{ vacancies_count }} job opening
            {% plural %}
                Showing {{ vacancies_count }} job openings
            {% endblocktrans %}
        </p>

        <div class="list-group">
            {% for vacancy in vacancies %}
                <a href="{{ vacancy.get_absolute_url }}" class="list-group-item">
                    {{ vacancy }}
                    {% if vacancy.start %}
                        <span>{{ vacancy.start|date }}</span>
                    {% endif %}
                </a>
            {% empty %}
                <div class="list-group-item">{% trans "No items available" %}</div>
            {% endfor %}
        </div>
    {% endif %}
</div>
