{% load i18n cms_tags %}

{% regroup object_list by category.id as categories %}
<ul class="jobs-items">
	{% for category in categories %}
	{% for job_opening in category.list %}
	<li>
		<p class="jobs-category"><a href="{{ category.grouper.get_absolute_url }}">{{ job_opening.category.name }}</a></p>
		<h3 class="jobs-title"><a href="{{ job_opening.get_absolute_url }}">{% render_model job_opening "title" %}</a></h3>
		<div class="jobs-lead">{% render_model job_opening "lead_in" "lead_in" safe %}</div>
		<p class="jobs-more"><a href="{{ job_opening.get_absolute_url }}">{% trans "read more" %}</a></p>
	</li>
	{% endfor %}
	{% empty %}
	<li class="jobs-empty"><p>{% trans "There are currently no job openings." %}</p></li>
	{% endfor %}
</ul>
