{% load i18n %}

<div class="plugin plugin-jobs">
    {% if plugin_configuration_error %}
        {% if request.user.is_staff or request.user.is_superuser %}
            <p class="config-errors">{{ plugin_configuration_error }}</p>
        {% endif %}
    {% else %}
        <ul class="jobs-latest-entries">
        {% for vacancy in vacancies %}
            <li><p><a href="{{ vacancy.get_absolute_url }}">{{ vacancy }}</a></p></li>
        {% empty %}
            <li class="jobs-empty"><p>{% trans "There are currently no job openings." %}</p></li>
        {% endfor %}
        </ul>
    {% endif %}
</div>
