{% extends "aldryn_jobs/two_column.html" %}
{% load i18n cms_tags %}

{% block jobs_content %}
    {% render_placeholder view.config.placeholder_jobs_list_top %}
    <div class="aldryn-jobs-list">
        {% regroup object_list by category as categories %}
        {% for category in categories %}
            {% for job_opening in category.list %}
                {% include "aldryn_jobs/includes/job.html" %}
            {% empty %}
                <p class="well">{% trans "No items available" %}</p>
            {% endfor %}
        {% empty %}
            <p class="well">{% trans "No items available" %}</p>
        {% endfor %}
    </div>
    {% render_placeholder view.config.placeholder_jobs_list_bottom %}
{% endblock %}
