{% extends "aldryn_jobs/fullwidth.html" %}
{% load i18n cms_tags apphooks_config_tags %}

{% block jobs_content %}
    {% render_placeholder view.config.placeholder_jobs_detail_top %}
    <div class="aldryn-jobs-detail">
        {% include "aldryn_jobs/includes/job.html" with job_opening=object detail_view="true" %}
    </div>
    {% render_placeholder view.config.placeholder_jobs_detail_bottom %}
{% endblock %}

{% block jobs_footer %}
    <div class="aldryn-jobs-pager">
        <ul class="pager">
            <li>
                <span class="pager-back">
                    – <a href="{% namespace_url 'job-opening-list' %}">
                        {% trans "Back to Overview" %}
                    </a> –
                </span>
            </li>
        </ul>
    </div>
    {% render_placeholder view.config.placeholder_jobs_detail_footer %}
{% endblock jobs_footer %}
