{% extends "emailit/base_email.body.html" %}
{% load i18n html_filter_tags %}

{% block content %}
    {% blocktrans with salutation=job_application.get_salutation_display first_name=job_application.first_name last_name=job_application.last_name context 'aldryn-jobs' %}
        <p>Dear {{ salutation }} {{ first_name }} {{ last_name }}</p>
    {% endblocktrans %}

    {% blocktrans context 'aldryn-jobs' %}
        <p>
            Due to the large quantity of applications received,
            it was a difficult task to short-list candidates and after careful
            consideration we have decided not to take your application any further.
            If you are still interested in employment with us, all our job openings
            are listed on our website, which is updated regularly.
            We are sorry that we cannot help you on this occasion,
            but would like to take this opportunity to thank you for the
            interest you have shown in us and to wish you every success
            with your future career.
        </p>

        <p>Kind regards</p>
        <p>Your HR team</p>
    {% endblocktrans %}
{% endblock %}
